@@ -21,7 +21,7 @@ urlpatterns = patterns('',
                        url(r'^reset/complete/$',
                            PasswordResetCompleteView.as_view(),
                            name="password_reset_complete"),
-                       url(r'^reset/confirm/([0-9A-Za-z]{1,13})/([0-9A-Za-z]{1,13})/(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)/$',
+                       url(r'^reset/confirm/([0-9A-Za-z]{1,13})/([0-9A-Za-z]{1,13})/([0-9A-Za-z-=_]{1,32})/$',
                            PasswordResetConfirmView.as_view(),
                            name="password_reset_confirm"),
                        url(r'^reset/done/$',
